You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jspwiki.apache.org by gm...@apache.org on 2013/08/22 13:54:08 UTC

svn commit: r1516423 - in /jspwiki/trunk: ChangeLog jspwiki-site/src/site/trunk/content/jspwiki/development/changelog.mdtext jspwiki-site/src/site/trunk/templates/release.mdtext jspwiki-war/src/main/java/org/apache/wiki/PropertyReader.java

Author: gmazza
Date: Thu Aug 22 11:54:07 2013
New Revision: 1516423

URL: http://svn.apache.org/r1516423
Log:
Updated names of some property constants to reflect new jspwiki-custom.properties

Modified:
    jspwiki/trunk/ChangeLog
    jspwiki/trunk/jspwiki-site/src/site/trunk/content/jspwiki/development/changelog.mdtext
    jspwiki/trunk/jspwiki-site/src/site/trunk/templates/release.mdtext
    jspwiki/trunk/jspwiki-war/src/main/java/org/apache/wiki/PropertyReader.java

Modified: jspwiki/trunk/ChangeLog
URL: http://svn.apache.org/viewvc/jspwiki/trunk/ChangeLog?rev=1516423&r1=1516422&r2=1516423&view=diff
==============================================================================
--- jspwiki/trunk/ChangeLog (original)
+++ jspwiki/trunk/ChangeLog Thu Aug 22 11:54:07 2013
@@ -1,5 +1,17 @@
 2013-08-17  Glen Mazza (gmazza AT apache DOT org)
 
+       * 2.10.0-svn-43
+
+       * Changed jspwiki.propertyfile.cascade to jspwiki.custom.cascade to emphasize cascading is done
+         on top of new jspwiki-custom.properties file if present, the default properties file only if not
+         present.
+
+       * Changed some internal constants from "propertyfile" to "custom" so they more accurately reflect
+         their meaning in 2.10.
+
+        
+2013-08-17  Glen Mazza (gmazza AT apache DOT org)
+
        * 2.10.0-svn-42
 
        * Updated code from using org.hsqldb.jdbcDriver to org.hsqldb.jdbc.JDBCDriver

Modified: jspwiki/trunk/jspwiki-site/src/site/trunk/content/jspwiki/development/changelog.mdtext
URL: http://svn.apache.org/viewvc/jspwiki/trunk/jspwiki-site/src/site/trunk/content/jspwiki/development/changelog.mdtext?rev=1516423&r1=1516422&r2=1516423&view=diff
==============================================================================
--- jspwiki/trunk/jspwiki-site/src/site/trunk/content/jspwiki/development/changelog.mdtext (original)
+++ jspwiki/trunk/jspwiki-site/src/site/trunk/content/jspwiki/development/changelog.mdtext Thu Aug 22 11:54:07 2013
@@ -1,5 +1,20 @@
 Title: Changelog
 
+#### 2013-08-17  Glen Mazza (gmazza AT apache DOT org)
+
+* 2.10.0-svn-42
+
+* Updated code from using org.hsqldb.jdbcDriver to org.hsqldb.jdbc.JDBCDriver
+
+* Switched from inaccurate NoRequiredPropertyException to somewhat better WikiSecurityException 
+  for database errors in JDBCGroup/UserDatabase (former was giving confusing error messages
+  when the underlying problem was just DB-related).
+
+* More work in IT tests, for JDBC tests to become operative again (not yet finished).
+
+* Renamed HsqlDbUtils to HsqlDBUtilsIT in it-tests, to fully ensure HsqlDBUtils in jspwiki-war
+  isn't being run instead.
+ 
 #### 2013-08-15  Glen Mazza (gmazza AT apache DOT org)
 
 * 2.10.0-svn-41

Modified: jspwiki/trunk/jspwiki-site/src/site/trunk/templates/release.mdtext
URL: http://svn.apache.org/viewvc/jspwiki/trunk/jspwiki-site/src/site/trunk/templates/release.mdtext?rev=1516423&r1=1516422&r2=1516423&view=diff
==============================================================================
--- jspwiki/trunk/jspwiki-site/src/site/trunk/templates/release.mdtext (original)
+++ jspwiki/trunk/jspwiki-site/src/site/trunk/templates/release.mdtext Thu Aug 22 11:54:07 2013
@@ -1 +1 @@
-JSPWiki v2.10.0-svn-41
\ No newline at end of file
+JSPWiki v2.10.0-svn-42
\ No newline at end of file

Modified: jspwiki/trunk/jspwiki-war/src/main/java/org/apache/wiki/PropertyReader.java
URL: http://svn.apache.org/viewvc/jspwiki/trunk/jspwiki-war/src/main/java/org/apache/wiki/PropertyReader.java?rev=1516423&r1=1516422&r2=1516423&view=diff
==============================================================================
--- jspwiki/trunk/jspwiki-war/src/main/java/org/apache/wiki/PropertyReader.java (original)
+++ jspwiki/trunk/jspwiki-war/src/main/java/org/apache/wiki/PropertyReader.java Thu Aug 22 11:54:07 2013
@@ -52,14 +52,14 @@ public final class PropertyReader
      *  uses the default as defined by DEFAULT_PROPERTYFILE.
      *  {@value #DEFAULT_JSPWIKI_CONFIG}
      */
-    public static final String PARAM_PROPERTYFILE = "jspwiki.custom.config";
+    public static final String PARAM_CUSTOMCONFIG = "jspwiki.custom.config";
 
     /**
      *  The prefix when you are cascading properties.  
      *  
      *  @see #loadWebAppProps(ServletContext)
      */
-    public static final String PARAM_PROPERTYFILE_CASCADEPREFIX = "jspwiki.custom.cascade.";
+    public static final String PARAM_CUSTOMCONFIG_CASCADEPREFIX = "jspwiki.custom.cascade.";
 
     public static final String  CUSTOM_JSPWIKI_CONFIG = "/jspwiki-custom.properties";
 
@@ -74,10 +74,10 @@ public final class PropertyReader
 
     /**
      *  Loads the webapp properties based on servlet context information, 
      *  or (if absent) based on the Java System Property PARAM_PROPERTYFILE .
      *  Returns a Properties object containing the settings, or null if unable
      *  to load it. (The default file is WEB-INF/jspwiki.properties, and can
      *  be overridden by setting PARAM_PROPERTYFILE in the server or webapp
      *  configuration.)
      *
      *  <h3>Cascading Properties</h3>
@@ -90,9 +90,9 @@ public final class PropertyReader
      *  <p>
      *  You define a cascade in the context mapping of your servlet container.
      *  <pre>
-     *  jspwiki.properties.cascade.1
-     *  jspwiki.properties.cascade.2
-     *  jspwiki.properties.cascade.3
+     *  jspwiki.custom.cascade.1
+     *  jspwiki.custom.cascade.2
+     *  jspwiki.custom.cascade.3
      *  </pre>
      *  and so on. You have to number your cascade in a descending way starting
      *  with "1". This means you cannot leave out numbers in your cascade. This
@@ -103,7 +103,7 @@ public final class PropertyReader
      */
     public static Properties loadWebAppProps( ServletContext context )
     {
-        String propertyFile = getInitParameter( context, PARAM_PROPERTYFILE );
+        String propertyFile = getInitParameter( context, PARAM_CUSTOMCONFIG);
         InputStream propertyStream = null;
 
         try
@@ -116,14 +116,14 @@ public final class PropertyReader
             //
             if( propertyFile == null )
             {
-                context.log("No " + PARAM_PROPERTYFILE + " defined for this context, " +
+                context.log("No " + PARAM_CUSTOMCONFIG + " defined for this context, " +
                         "looking for custom properties file with default name of: " + CUSTOM_JSPWIKI_CONFIG);
                 //  Use the custom property file at the default location
                 propertyStream = config_class.getResourceAsStream(CUSTOM_JSPWIKI_CONFIG);
             }
             else
             {
-                context.log(PARAM_PROPERTYFILE + " defined, using " + propertyFile + " as the custom properties file.");
+                context.log(PARAM_CUSTOMCONFIG + " defined, using " + propertyFile + " as the custom properties file.");
                 propertyStream = new FileInputStream( new File(propertyFile) );
             }
 
@@ -271,7 +271,7 @@ public final class PropertyReader
      */
     private static void loadWebAppPropsCascade(ServletContext context, Properties defaultProperties)
     {
-        if( getInitParameter(context,PARAM_PROPERTYFILE_CASCADEPREFIX + "1") == null )
+        if( getInitParameter(context, PARAM_CUSTOMCONFIG_CASCADEPREFIX + "1") == null )
         {
             context.log(" No cascading properties defined for this context");
             return;
@@ -284,7 +284,7 @@ public final class PropertyReader
         while (more)
         {
             depth++;
-            String propertyFile = getInitParameter(context,PARAM_PROPERTYFILE_CASCADEPREFIX + depth);
+            String propertyFile = getInitParameter(context, PARAM_CUSTOMCONFIG_CASCADEPREFIX + depth);
 
             if (propertyFile == null)
             {
@@ -74,10 +74,10 @@ public final class PropertyReader
     /**
      *  Loads the webapp properties based on servlet context information, 
-     *  or (if absent) based on the Java System Property PARAM_PROPERTYFILE .
+     *  or (if absent) based on the Java System Property PARAM_CUSTOMCONFIG .
      *  Returns a Properties object containing the settings, or null if unable
@@ -74,10 +74,10 @@ public final class PropertyReader
      *  Returns a Properties object containing the settings, or null if unable
-     *  to load it. (The default file is WEB-INF/jspwiki.properties, and can
-     *  be overridden by setting PARAM_PROPERTYFILE in the server or webapp
+     *  to load it. (The default file is ini/jspwiki.properties, and can
+     *  be customized by setting PARAM_CUSTOMCONFIG in the server or webapp
      *  configuration.)
      *